
#include <looptime.h>

/* 6/27/2015 - Modified by AIAA OC Rocketry
             Directions referenced to top of MMA7361LC 3 axis accelerometer sitting flat on a table using the accelerometer's reference of "x", "y", and "z"
                                              --------------------
                                        GND   |1-GND       Vdd-10|  3.3VDC
              ^                               |                  |
              | (towards top of board)  AN1   |2-X         Test-9|  NC
              |                               |                  |
              <----  (to the left)      AN2   |3-Y         GSel-8|  Center of 1K Ohm Divider to ~6 on UNO (to scale Arduino Uno 5V to MMA7361LC at 3.3V)
                                              |                  |
              0      (up off the table) AN3   |4-Z        Sleep-7|  3.3VDC
                                              |                  |
                                        GND   |5-GND  0g-Detect-6|  NC
                                              --------------------
    Mapping of these axes to the CanSat:
         CanSat's "X" axis is read from AN2 which is connected to the MMA7361L "Y" axis (shifting the accelerometer, in the above orientation, left and right)
         CanSat's "Y" axis is read from AN3 which is connected to the MMA7361L "Z" axis (shifting the accelerometer, in the above orientation towards you and away from you)
         CanSat's "Z" axis is read from AN1 which is connected to the MMA7361L "X" axis (shifting the accelerometer, in the above orientation, up and down)
                                              
    Added defines for the A/D channels instead of having values hard coded
*/

/* calib of mma7361L
 AAU cansatshield v3.2
 Pin8 on acc shall be connected to D8 for switching sensitivity
 */

// Define which A/D port is connected to the X, Y, and Z axes of the accelerometer
#define AccelXaxis 2   // Pin 2 of MMA7361L
#define AccelYaxis 3   // Pin 3 of MMA7361L
#define AccelZaxis 1   // Pin 4 of MMA7361L

#define VRS 01
#define NRSUM 150
#define LOOPTIME 20

void setup()
{
  Serial.begin(9600);
  pinMode(8,OUTPUT);
  digitalWrite(8,LOW);
  Serial.print("Acc calibg vrs 1.5g and 6g version: ");
  Serial.println(VRS);
}

int 
x1,x0,x_1, 
y1,y0,y_1, 
z1, z0, z_1,
x11,x10,x1_1, 
y11,y10,y1_1, 
z11, z10, z1_1; 

long xmean, ymean, zmean;

void mm()
{
  int c;
  looptime(0);
  xmean=ymean=zmean = 0; // reset
  for (c = 0 ; c < NRSUM ; c++) {
    xmean += analogRead(AccelYaxis);
    ymean += analogRead(AccelZaxis);
    zmean += analogRead(AccelXaxis);
    looptime(LOOPTIME);
  }
  xmean /=NRSUM;
  ymean /=NRSUM;
  zmean /=NRSUM;
}

void st()
{
  int c;
  while (0 < Serial.available()) 
    c = Serial.read(); // empty buffer
  Serial.println("press a key for start");
  while (0 == Serial.available() ) ;
  Serial.println("..");
  delay(3000);
}

void mea()
{
//  Serial.println("Calib 1 - arduino on feets...");
  Serial.println("Calib 1 - CanSat on side with pins 1-5 on accelerometer UP");
  // x0, y0 z1
  st();
  mm();
  x0 = xmean; 
  y0 = ymean; 
  z1 = zmean;

//  Serial.println("Calib 2 -upside down");
  Serial.println("Calib 2 - CanSat on side with pins 1-5 on accelerometer DOWN");
  // x0, y0, z_1
  st();
  mm();
  z_1 = zmean;

//  Serial.println("Calib 3 - stand on battery end");
  Serial.println("Calib 3 - CanSat on side with component side of accelerometer UP");
  // x1 y0 z0
  st();
  mm();
  x1 = xmean; 
  z0 = zmean;

//  Serial.println("Calib 4 - stand on opposite end");
  Serial.println("Calib 4 - CanSat on side with component side of accelerometer DOWN");
  // x_1 y0 z0
  st();
  mm();
  x_1 = xmean;


//  Serial.println("Calib 5 -  on radio side");
  Serial.println("Calib 5 - CanSat on side with pins 1 & 10 on accelerometer UP");
  // x0 y1 z0
  st();
  mm();
  y_1 = ymean;

//  Serial.println("Calib 6 -  on analog side");
  Serial.println("Calib 6 - CanSat on side with pins 1 & 10 on accelerometer DOWN");
  // x0 y_1 z0
  st();
  mm();
  y1 = ymean;
}


void sort()
{
  int tmp;
  if (x1 < x_1) {
    tmp = x1;
    x1 = x_1;
    x_1 = tmp;
  }
  if (y1 < y_1) {
    tmp = y1;
    y1 = y_1;
    y_1 = tmp;
  }
  if (z1 < z_1) {
    tmp = z1;
    z1 = z_1;
    z_1 = tmp;
  }
}


void dmp()
{
  Serial.println("-----------------------");
  Serial.print("x: ");
  Serial.print(x_1); 
  Serial.print(" "); 
  Serial.print(x0);
  Serial.print(" "); 
  Serial.println(x1);

  Serial.print("y: ");
  Serial.print(y_1); 
  Serial.print(" "); 
  Serial.print(y0);
  Serial.print(" "); 
  Serial.println(y1);
  Serial.print("z: ");
  Serial.print(z_1); 
  Serial.print(" "); 
  Serial.print(z0);
  Serial.print(" "); 
  Serial.println(z1);
}

void loop()
{
  int c;
  mea();
  sort();
  dmp();
  x1_1 = x_1; 
  x10 = x0; 
  x11 = x1;
  y1_1 = y_1; 
  y10 = y0; 
  y11 = y1;
  z1_1 = z_1; 
  z10 = z0; 
  z11 = z1;
  while (0 < Serial.available()) 
    c = Serial.read(); // empty buffer
  digitalWrite(8,HIGH);
  Serial.println("press key for 6g measurements");
  while (0 == Serial.available() ) ;
  mea();
  sort();
  Serial.println("6g results");
  dmp();
  Serial.println("1.5 g results");
  x_1 = x1_1; 
  x0 = x10; 
  x1 = x11;  
  y_1 = y1_1; 
  y0 = y10; 
  y1 = y11;  
  z_1 = z1_1; 
  z0 = z10; 
  z1 = z11;
  dmp();  
  while(1);
}








